macroScript htVRMapMerge category:"CANPLAIZE" tooltip:"Merging V-ray irradiance maps"
(
	local checked = false
	local iniFile = "$plugcfg/htVRMapMerge.ini"
	
	/* read setting file "htVRMapMerge.ini" */
	vPathToVRMapViewer = getINISetting iniFile "setting" "PathToVRMapViewer"
	if vPathToVRMapViewer == "" do vPathToVRMapViewer = ""
	
	function selectVRMapFiles = (
		/* create a OpenFileDialog (Dot NET Object:Multi file selection) */
		theDialog = dotNetObject "System.Windows.Forms.OpenFileDialog"
		theDialog.title = "Select .vrmap files"
		theDialog.Multiselect = true
		theDialog.Filter = "irradiance map file(*.vrmap)|*.vrmap|All Files (*.*)|*.*"
		theDialog.FilterIndex = 1
		
		/* initialize last open directory */
		lastOpenPath = getINISetting iniFile "setting" "lastOpenPath"
		theDialog.InitialDirectory = lastOpenPath
		
		result = theDialog.showDialog()
		result.ToString()
		--result.Equals result.OK
		if result.Equals result.Cancel do return theFilenames = ""
		theFilenames = theDialog.fileNames
		setINISetting iniFile "setting" "lastOpenPath" (getFilenamePath theFilenames[1])
		return theFilenames
	)
	
	rollout htVRMapMergeDialog "V-ray irradiance map merger (Front-end)" width:408 height:240
	(
		/* Build UIs */
		label lbl1 "Path to Irradiance Map Viewer \"imapviewer.exe\"" pos:[8,8] width:408 height:16
		editText edtPathVRMapViewer "" text:vPathToVRMapViewer pos:[5,24] width:320 height:16
		button btnBrowseVRMapViewer "Browse..." pos:[336,24] width:64 height:16
		
		MultiListBox vrlist ".vrmap List" pos:[8,48] width:392 height:7
		button btnBrowseVmapsAdd "Add..." pos:[150,155] width:120 height:16
		button btnBrowseVmaps "Clear&Select..." pos:[280,155] width:120 height:16
		
		label lbl2 "Out file" pos:[8,176] width:136 height:16
		editText edtOutFile "" pos:[5,192] width:320 height:16
		button btnBrowseOutFile "Browse..." pos:[336,192] width:64 height:16
		
		button btnExecuteMerge "Merge!" pos:[152,216] width:120 height:16
		/* End of Build UIs */
		
		on btnBrowseVRMapViewer pressed do
		(
			rst = getOpenFileName caption:"Select imapviewer.exe" types:"imapviewer.exe(*.exe)|*.exe"
			if rst != undefined do
			(
				edtPathVRMapViewer.text = rst
				setINISetting iniFile "setting" "PathToVRMapViewer" rst
			)
		)
		
		on btnBrowseVmapsAdd pressed do
		(
			rst = selectVRMapFiles()
			if rst != "" do
			(
				vrlist.items = join vrlist.items rst
			)
		)
		
		on btnBrowseVmaps pressed do
		(
			rst = selectVRMapFiles()
			if rst != "" do
			(
				vrlist.items = rst
			)
		)
		
		
		on btnBrowseOutFile pressed do
		(
			lastSavePath = getINISetting iniFile "setting" "lastSavePath"
			outFilePath = getSaveFileName caption:"Save merged file" filename:lastSavePath types:"irradiance map file(*.vrmap)|*.vrmap|All Files (*.*)|*.*"
			if outFilePath != undefined do
			(
				edtOutFile.text = outFilePath
				setINISetting iniFile "setting" "lastSavePath" outFilePath
			)
		)
		
		on btnExecuteMerge pressed do
		(
			/* 	check (Not yet)
				imapviewer.exe exists!
				vrmap list includes 2 more!
				output file!
			*/
			
			chkFlag = 3
			/* end check */
			
			if chkFlag == 3 then
			(
				/* Build command line strings */
				inFileString = ""
				outFileString = ""
				for i = 1 to vrlist.items.count do
				(
					--inFileString += (" -load "+ "\"" + vrlist.items[i] + "\"")
					inFileString += (" -load "+ vrlist.items[i])
				)
				--outFileString = " -save " + "\"" + edtOutFile.text + "\""
				outFileString = " -save " + edtOutFile.text
				commandString = ("\"" + edtPathVRMapViewer.text + "\"")
					
				completeString = (commandString + inFileString + outFileString + " -nodisplay")
							
				print completeString
				DOSCommand completeString
			)
			else
			(
				/* not yet */
			)
		)
		
		on htVRMapMergeDialog close do
		(
			checked = false
			updateToolbarButtons()
		)
	)
	
	on execute do	
	(
		createDialog htVRMapMergeDialog
		checked = true
	)
	
	on closeDialogs do
	(
		destroyDialog htVRMapMergeDialog
	)
	on isChecked return (checked)
)